# Flashday
> This intend to be an [readme-documented][-0], [open-source-licensed][-1], [semantic-versioned][-2],
[conventional-committed][-3] and [changelogged][-4] git repository for the development of a 
[pripessoaink][1] namespace's python package

Flashday event Django app

[-0]: https://www.makeareadme.com/ "Make a README"
[-1]: https://choosealicense.com/licenses/ "Choose a License"
[-2]: https://semver.org/ "Semantic Versioning"
[-3]: https://www.conventionalcommits.org/en/v1.0.0/ "Conventional Commits"
[-4]: https://keepachangelog.com/en/1.0.0/ "Keep a Changelog"
[-5]: https://www.repostatus.org "Repo maintenance status"

[1]: https://www.instagram.com/pripessoaink/ "Pripessoaink"

This package brings the tools to serve a Flashday event as a service through Django server


## Maintainance [![][B1]][-5]
This project is maintained by the author, [@artu-hnrq](https://github.com/artu-hnrq). \
It has reached a stable, usable state and is being **actively developed**.

[B1]: https://www.repostatus.org/badges/latest/active.svg "Repostatus active badge"


## License [![][B2]][2]
This project is published under the permissions established by [GNU General Public License v3.0][6].

[B2]: https://img.shields.io/github/license/artu-hnrq/Django_GoogleAppEngine_Template?color=green "License badge"
[2]: https://choosealicense.com/licenses/gpl-3.0/ "GPL 3.0 License description"
